Ed25519VerifyInternalArgs

Struct Ed25519VerifyInternalArgs 

#[repr(C)]
pub struct Ed25519VerifyInternalArgs {
Show 15 fields pub public_key_ptr: u64, pub public_key_size: u32, pub public_key_capacity: u32, pub signature_ptr: u64, pub signature_size: u32, pub signature_capacity: u32, pub message_ptr: u64, pub message_size: u32, pub message_capacity: u32, pub result_ptr: u64, pub public_key: Ed25519PublicKey, pub signature: Ed25519Signature, pub message: [u8; 32], pub result: Bool, pub padding: [u8; 7],
}
Helper data structure for Benchmarks::ed25519_verify() method

Fields

public_key_ptr: u64public_key_size: u32public_key_capacity: u32signature_ptr: u64signature_size: u32signature_capacity: u32message_ptr: u64message_size: u32message_capacity: u32result_ptr: u64public_key: Ed25519PublicKeysignature: Ed25519Signaturemessage: [u8; 32]result: Boolpadding: [u8; 7]

Explicit trailing padding.

The host copies the byte representation of this data structure into guest memory, which is only sound if every byte of it is initialized, hence implicit padding must not exist here.

Implementations

Source

impl Ed25519VerifyInternalArgs

pub fn new( internal_args_addr: u64, public_key: Ed25519PublicKey, signature: Ed25519Signature, message: [u8; 32], ) -> Self

Create a new instance

pub fn result(&self) -> Bool

Extract result