pub struct LazyInstructionFetcher { /* private fields */ }Expand description
Lazy instruction fetcher implementation
Implementations
Sourceimpl LazyInstructionFetcher
impl LazyInstructionFetcher
Sourcepub unsafe fn new(return_trap_address: u64, pc: u64) -> Self
pub unsafe fn new(return_trap_address: u64, pc: u64) -> Self
Create a new instance.
return_trap_address is the address at which the interpreter will stop execution
(gracefully).
Safety
The program counter must be valid and aligned, the instructions processed must be valid and end with a jump instruction.